<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg">
<context>
    <name>OutputALSAFactory</name>
    <message>
        <location filename="../outputalsafactory.cpp" line="31"/>
        <source>ALSA Plugin</source>
        <translation>ALSA приставка</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="56"/>
        <source>About ALSA Output Plugin</source>
        <translation>Относно приставката за изход ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="57"/>
        <source>Qmmp ALSA Output Plugin</source>
        <translation>Qmmp приставката за изход ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="58"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Написана от Илия Котов &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ALSA Plugin Settings</source>
        <translation>Настройка на приставката ALSA</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Device Settings</source>
        <translation>Настройка на устройството</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Audio device</source>
        <translation>Звуково устройство</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Mixer</source>
        <translation>Смесител</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Mixer card:</source>
        <translation>Смесителна карта</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="86"/>
        <source>Mixer device:</source>
        <translation>Смесително устройство</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>Advanced Settings</source>
        <translation>Настройки за напреднали</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="115"/>
        <source>Soundcard</source>
        <translation>Звукова карта</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="121"/>
        <source>Buffer time (ms):</source>
        <translation>Време на буфера (ms)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="157"/>
        <source>Period time (ms):</source>
        <translation>Време период (ms)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="193"/>
        <source>Use mmap access</source>
        <translation>Използвай mmap достъп</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="213"/>
        <source>Use snd_pcm_pause function</source>
        <translation>Използвай snd_pcm_pause функция</translation>
    </message>
</context>
</TS>
